Installation
============

From Pip
-----------

.. code-block:: bash

    pip install echelle

From Source
-----------

.. code-block:: bash

    git clone --recursive https://github.com/danhey/echelle.git
    cd echelle
    python setup.py install


    